@@ -31,7 +31,7 @@ sub perform {
 
 sub remove { $_[0]->minion->backend->remove_job($_[0]->id) }
 
-sub restart { $_[0]->minion->backend->restart_job($_[0]->id) }
+sub retry { $_[0]->minion->backend->retry_job($_[0]->id) }
 
 sub _child {
   my $self = shift;
@@ -195,9 +195,9 @@ Perform job in new process and wait for it to finish.
 
 Remove C<failed>, C<finished> or C<inactive> job from queue.
 
-=head2 restart
+=head2 retry
 
-  my $bool = $job->restart;
+  my $bool = $job->retry;
 
 Transition from C<failed> or C<finished> state back to C<inactive>.
 
